const { Pool } = require("pg");
const logger = require("../../config/logger"); // Corrected logger path

// Load environment variables
// require('dotenv').config(); // Call this at the very start of your app, e.g. in server.js

const pool = new Pool({
	connectionString: process.env.DATABASE_URL,
	ssl: {
		rejectUnauthorized: false, // Necessary for some cloud providers, including Neon
	},
	// user: process.env.DB_USER,
	// host: process.env.DB_HOST,
	// database: process.env.DB_NAME,
	// password: process.env.DB_PASSWORD,
	// port: process.env.DB_PORT || 5432, // Default PostgreSQL port
	// Optional: Add more pool configuration options if needed
	// max: 20, // Max number of clients in the pool
	// idleTimeoutMillis: 30000, // How long a client is allowed to remain idle before being closed
	// connectionTimeoutMillis: 2000, // How long to wait for a connection from the pool
});

pool.on("connect", (client) => {
	logger.info("New client connected to the PostgreSQL database");
	// You can set session-level parameters here if needed, e.g.:
	// client.query('SET TIMEZONE="UTC";');
});

pool.on("error", (err, client) => {
	logger.error("Unexpected error on idle PostgreSQL client", {
		error: err.message,
		clientInfo: client ? `Client connected for ${client.processID}` : "N/A",
	});
	// process.exit(-1); // Consider if you want to exit on idle client errors
});

// Test the connection (optional, but good for startup diagnostics)
async function testConnection() {
	try {
		const client = await pool.connect();
		logger.info("Successfully connected to PostgreSQL database via pool.");
		const res = await client.query("SELECT NOW()");
		logger.info(`PostgreSQL current time: ${res.rows[0].now}`);
		client.release();
	} catch (err) {
		logger.error("Failed to connect to PostgreSQL database:", err.stack);
		// process.exit(1); // Exit if DB connection is critical for startup
	}
}

testConnection();

module.exports = pool; // Export the pool
